#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/access'
require 'easy_type'

Puppet::Type.type(:ora_object_grant).provide(:prefetching) do
  include EasyType::Provider
  include EasyType::Helpers
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::Information
  include EasyType::Template

  confine :exists => '/etc/ora_setting.yaml'

  desc 'Manage Oracle object permissions via regular SQL'

  mk_resource_methods

  def self.all_resources
    where_clauses = []
    statement = for_version(
      :'12'     => template('ora_config/ora_object_grant/index_v12.sql.erb', binding),
      :default  => template('ora_config/ora_object_grant/index.sql.erb', binding)
    )
    sql_on_all_database_sids(statement)
  end

  def self.instances_for(resources)
    where_clauses = resources.map do | key, resource|
      owner, table_name = resource.object_name.split('.')
      "(grantee = '#{resource.grantee}' and owner = '#{owner}' and table_name = '#{table_name}')"
    end
    statement = for_version(
      :'12'     => template('ora_config/ora_object_grant/index_v12.sql.erb', binding),
      :default  => template('ora_config/ora_object_grant/index.sql.erb', binding)
    )
    raw_resources = sql_on_all_database_sids(statement)
    raw_resources.map do |raw_resource|
      map_raw_to_resource(raw_resource)
    end
  end

  def self.prefetch(resources)
    objects = instances_for(resources)
    resources.each_key do |name|
      provider = objects.find { |object| object.name == name }
      resources[name].provider = provider if provider
    end
  end

end
