#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:job_type) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    Specifies what type of job it is. Supported values are `PLSQL_BLOCK` and `STORED_PROCEDURE`.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          job_type => 'STORED_PROCEDURE',
          ...
        }

    Puppet doesn't provide a default value.

  EOD

  newvalues('PLSQL_BLOCK', 'STORED_PROCEDURE')

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('JOB_TYPE')
  end

  on_modify do
    statement = template('ora_config/ora_scheduler_job/modify_quoted_attribute.sql.erb', binding)
    sql statement, {:sid => resource.sid}
  end

end
