#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:repeat_interval) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    Specifies the frequency at which to run the job.
    A PL/SQL function can be used that returns the next date and time to run or
    a calendering syntax expression can be used.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          repeat_interval => 'FREQ=HOURLY;INTERVAL=1',
          ...
        }

    Puppet doesn't provide a default value.

  EOD
  
  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('REPEAT_INTERVAL')
  end

  on_modify do
    if resource.repeat_interval == '' or resource.repeat_interval.nil?
      statement = "begin dbms_scheduler.set_attribute_null(name => '#{resource.owner}.#{resource.job_name}', attribute => 'REPEAT_INTERVAL'); end;\n/\n"
    else
      statement = template('ora_config/ora_scheduler_job/modify_quoted_attribute.sql.erb', binding)
    end
    sql statement, {:sid => resource.sid}
  end

end
