#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:autoextend) do
  include EasyType
  include TablespaceType
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::DatafileProperty

  desc <<-EOD
    Enable autoextension for the tablespace.
  EOD

  newvalues(:on, :off)
  aliasvalue(:yes, :on)
  aliasvalue(:no, :off)
  aliasvalue(true, :on)
  aliasvalue(false, :off)

  to_translate_to_resource do |raw_resource|
    case raw_resource.column_data('AUT')
    when 'YES' then :on
    when 'NO' then :off
    else
      fail('Invalid autoxtend found in tablespace resource.')
    end
  end

  on_modify do
    if resource[:autoextend] == :off
      if resource[:max_size]
        Puppet.warning "#{path}: property max_size changed on ora_tablespace[#{resource[:name]}], but autoextend is off. Change has no effect. "
      end
      if resource[:next]
        Puppet.warning "#{path}: property next changed on ora_tablespace[#{resource[:name]}], but autoextend is off. Change has no effect. "
      end
    end
    provider.datafile.each do |df|
      sql("alter database #{tablespace_type} '#{df}' #{autoextend_spec}", :sid => resource.sid)
    end
  end

  on_create do
    # only add autoextend clause to command if there is only one datafile
    "autoextend #{resource[:autoextend]}" unless ( df_array_size(resource.datafile) > 1 or desired_num_datafiles > 1 )
  end

end
